
# THIS FILE IS GENERATED FROM PYART SETUP.PY
short_version = '1.9.2'
version = '1.9.2'
full_version = '1.9.2'
git_revision = 'af43d4e7d7b537c5542672cb878c2c7f4918045e'
release = True

if not release:
    version = full_version
